<?php

namespace Tollwerk\TwOdl\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Joschi Kuphal <joschi@tollwerk.de>, tollwerk® GmbH
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Device controller
 *
 * @package tw_odl
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class DeviceController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {
	
	/**
	 * Device repository
	 *
	 * @var \Tollwerk\TwOdl\Domain\Repository\DeviceRepository
	 */
	protected $deviceRepository;
	
	/**
	 * Inject device repository
	 *
	 * @param \Tollwerk\TwOdl\Domain\Repository\DeviceRepository $deviceRepository
	 * @return void
	 */
	public function injectVideoRepository(\Tollwerk\TwOdl\Domain\Repository\DeviceRepository $deviceRepository) {
		$this->deviceRepository = $deviceRepository;
	}

	/**
	 * action list
	 *
	 * @return void
	 */
	public function listAction() {
		$devices = $this->deviceRepository->findAll();
		$this->view->assign('devices', $devices);
	}

	/**
	 * Return a complete device list as JSON file
	 * 
	 * @return string				JSON(P) device directory
	 */
	public function jsonpAction() {
		$devices				= array();
		
		/* @var $device \Tollwerk\TwOdl\Domain\Model\Device */
		foreach ($this->deviceRepository->findAll() as $device) {
			$devices[]			= $device->toArray();
		}
		
		$json					= @json_encode($devices);
		$callback				= trim(\TYPO3\CMS\Core\Utility\GeneralUtility::_GP('callback'));
		$callback				= strlen($callback) ? $callback : trim(\TYPO3\CMS\Core\Utility\GeneralUtility::_GP('jsonp'));
		
		// If it's a JSONP call
		if (strlen($callback)) {
			$json				= $callback.'('.$json.');';
			$contentType		= 'application/javascript';
			
		// Else
		} else {
			$contentType		= 'application/json';
		}
		
		ob_end_clean();
		header('Content-Type: '.$contentType);
		die($json);
	}
}

?>